==> workbench_approver-1.0.0.tar.gz: workbench_approver/src/Plugin/Block/ApproverBlock.php <==
<?php

namespace Drupal\workbench_approver\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RedirectDestinationTrait;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\Url;
use Drupal\node\NodeInterface;
use Drupal\workbench_approver\Entity\ApproverInterface;
use Drupal\workbench_approver\Services\ApproverManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A block that loads the approval forms.
 *
 * @Block(
 *   id = "workbench_approver_block",
 *   admin_label = @Translation("Workbench approver form")
 * )
 */
class ApproverBlock extends BlockBase implements ContainerFactoryPluginInterface {

  use RedirectDestinationTrait;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * The approver manager service.
   *
   * @var \Drupal\workbench_approver\Services\ApproverManagerInterface
   */
  protected $approverManager;

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Constructs an ApproverBlock object.
   *
   * @param array $configuration
   *   Configuration.
   * @param string $plugin_id
   *   ID.
   * @param array|object $plugin_definition
   *   Definition.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match service.
   * @param \Drupal\workbench_approver\Services\ApproverManagerInterface $approver_manager
   *   The entity type manager.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   The current user.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    RouteMatchInterface $route_match,
    ApproverManagerInterface $approver_manager,
    AccountProxyInterface $current_user,
    FormBuilderInterface $form_builder,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->routeMatch = $route_match;
    $this->approverManager = $approver_manager;
    $this->currentUser = $current_user;
    $this->formBuilder = $form_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match'),
      $container->get('workbench_approver.manager'),
      $container->get('current_user'),
      $container->get('form_builder')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $block = [];
    $route = $this->routeMatch->getRouteName();
    $node = $this->routeMatch->getParameter('node');

    $allowed_route = in_array($route, [
      'entity.node.canonical',
      'entity.node.latest_version',
    ], TRUE);

    // This block is only visible on the latest unpublished revision.
    if ($node instanceof NodeInterface && $allowed_route && $node->isLatestRevision() && !$node->isPublished()) {
      $user_approval_request = $this->approverManager->getApprovalRequestByUser($node, $this->currentUser, FALSE);
      if ($user_approval_request !== NULL) {
        $block['wrapper'] = [
          '#type' => 'fieldset',
        ];
        if ($user_approval_request->getStatus() === ApproverInterface::APPROVAL_PENDING) {
          $date = $user_approval_request->get('deadline')->value;
          $block['wrapper']['help'] = [
            '#markup' => $this->t('Your review of this revision has been requested by %name to be completed by @date.',
              [
                '%name' => $user_approval_request->getOwner()->label(),
                '@date' => date('d-M-Y', $date),
              ]),
            '#prefix' => '<p>',
            '#suffix' => '</p>',
          ];
          $block['wrapper']['approve'] = [
            '#title' => $this->t('Approve revision'),
            '#type' => 'link',
            '#url' => $this->ensureDestination($user_approval_request->toUrl('approve-form')),
            '#ajax' => [
              'dialogType' => 'modal',
              'dialog' => ['height' => 400, 'width' => 880],
            ],
            '#attributes' => [
              'class' => ['button--primary', 'button'],
              'role' => 'button',
            ],
          ];
          $block['wrapper']['reject'] = [
            '#title' => $this->t('Request changes'),
            '#type' => 'link',
            '#url' => $this->ensureDestination($user_approval_request->toUrl('reject-form')),
            '#ajax' => [
              'dialogType' => 'modal',
              'dialog' => ['height' => 440, 'width' => 880],
            ],
            '#attributes' => [
              'class' => ['button--secondary', 'button'],
              'role' => 'button',
            ],
          ];
        }
        else {
          $date = $user_approval_request->get('changed')->value;
          $block['wrapper']['help'] = [
            '#markup' => $this->t('You %status this revision on @date.',
              [
                '%status' => $user_approval_request->getStatusName(),
                '@date' => date('d-M-Y', $date),
              ]),
            '#prefix' => '<p>',
            '#suffix' => '</p>',
          ];
        }
      }
      // Add information for users who can see it.
      if ($this->approverManager->isViewer()) {
        // @todo There may be a better way to handle this case.
        $approval_requests = $this->approverManager->getApprovalRequests($node);
        $pending = $blocking = 0;
        foreach ($approval_requests as $request) {
          if ($request->isPending()) {
            $pending++;
          }
          if ($request->isBlocking()) {
            $blocking++;
          }
        }
        if ($pending > 0) {
          if (!isset($block['wrapper'])) {
            $block['wrapper'] = [
              '#type' => 'fieldset',
            ];
          }
          $block['wrapper']['info'] = [
            '#markup' => $this->formatPlural($pending,
              'There is 1 <a href="@link">outstanding approval request</a> for this revision.',
              'There are @count <a href="@link">outstanding approval requests</a> for this revision.',
              [
                '@count' => $pending,
                '@link' => '/node/' . $node->id() . '/approver',
              ]),
            '#prefix' => '<p>',
            '#suffix' => '</p>',
          ];
        }
        if ($blocking > 0) {
          if (!isset($block['wrapper'])) {
            $block['wrapper'] = [
              '#type' => 'fieldset',
            ];
          }
          $block['wrapper']['blocked'] = [
            '#markup' => $this->t('This content may not be set to a new moderation state.'),
            '#prefix' => '<p>',
            '#suffix' => '</p>',
          ];
        }
      }
    }

    return $block;
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    $permissions = [
      'use workbench approver',
      'view workbench approver information',
    ];
    return AccessResult::allowedIfHasPermissions($account, $permissions, 'OR');
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    return ['route.name', 'user'];
  }

  /**
   * Ensures that a destination is present on the given URL.
   *
   * @param \Drupal\Core\Url $url
   *   The URL object to which the destination should be added.
   *
   * @return \Drupal\Core\Url
   *   The updated URL object.
   */
  protected function ensureDestination(Url $url) {
    return $url->mergeOptions(['query' => $this->getRedirectDestination()->getAsArray()]);
  }

}

==> workbench_approver-1.0.1.tar.gz: workbench_approver/src/Plugin/Block/ApproverBlock.php <==
<?php

namespace Drupal\workbench_approver\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\RedirectDestinationTrait;
use Drupal\Core\Routing\RouteMatchInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\Url;
use Drupal\node\NodeInterface;
use Drupal\workbench_approver\Entity\ApproverInterface;
use Drupal\workbench_approver\Services\ApproverManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * A block that loads the approval forms.
 *
 * @Block(
 *   id = "workbench_approver_block",
 *   admin_label = @Translation("Workbench Approver form")
 * )
 */
class ApproverBlock extends BlockBase implements ContainerFactoryPluginInterface {

  use RedirectDestinationTrait;

  /**
   * The module handler.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * The approver manager service.
   *
   * @var \Drupal\workbench_approver\Services\ApproverManagerInterface
   */
  protected $approverManager;

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Constructs an ApproverBlock object.
   *
   * @param array $configuration
   *   Configuration.
   * @param string $plugin_id
   *   ID.
   * @param array|object $plugin_definition
   *   Definition.
   * @param \Drupal\Core\Routing\RouteMatchInterface $route_match
   *   The route match service.
   * @param \Drupal\workbench_approver\Services\ApproverManagerInterface $approver_manager
   *   The entity type manager.
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   The current user.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder.
   */
  public function __construct(
    array $configuration,
    $plugin_id,
    $plugin_definition,
    RouteMatchInterface $route_match,
    ApproverManagerInterface $approver_manager,
    AccountProxyInterface $current_user,
    FormBuilderInterface $form_builder,
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->routeMatch = $route_match;
    $this->approverManager = $approver_manager;
    $this->currentUser = $current_user;
    $this->formBuilder = $form_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match'),
      $container->get('workbench_approver.manager'),
      $container->get('current_user'),
      $container->get('form_builder')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $block = [];
    $route = $this->routeMatch->getRouteName();
    $node = $this->routeMatch->getParameter('node');

    $allowed_route = in_array($route, [
      'entity.node.canonical',
      'entity.node.latest_version',
    ], TRUE);

    // This block is only visible on the latest unpublished revision.
    if ($node instanceof NodeInterface && $allowed_route && $node->isLatestRevision() && !$node->isPublished()) {
      $user_approval_request = $this->approverManager->getApprovalRequestByUser($node, $this->currentUser, FALSE);
      if ($user_approval_request !== NULL) {
        $block['wrapper'] = [
          '#type' => 'fieldset',
        ];
        if ($user_approval_request->getStatus() === ApproverInterface::APPROVAL_PENDING) {
          $date = $user_approval_request->get('deadline')->value;
          $block['wrapper']['help'] = [
            '#markup' => $this->t('Your review of this revision has been requested by %name to be completed by @date.',
              [
                '%name' => $user_approval_request->getOwner()->label(),
                '@date' => date('d-M-Y', $date),
              ]),
            '#prefix' => '<p>',
            '#suffix' => '</p>',
          ];
          $block['wrapper']['approve'] = [
            '#title' => $this->t('Approve revision'),
            '#type' => 'link',
            '#url' => $this->ensureDestination($user_approval_request->toUrl('approve-form')),
            '#ajax' => [
              'dialogType' => 'modal',
              'dialog' => ['height' => 400, 'width' => 880],
            ],
            '#attributes' => [
              'class' => ['button--primary', 'button'],
              'role' => 'button',
            ],
          ];
          $block['wrapper']['reject'] = [
            '#title' => $this->t('Request changes'),
            '#type' => 'link',
            '#url' => $this->ensureDestination($user_approval_request->toUrl('reject-form')),
            '#ajax' => [
              'dialogType' => 'modal',
              'dialog' => ['height' => 440, 'width' => 880],
            ],
            '#attributes' => [
              'class' => ['button--secondary', 'button'],
              'role' => 'button',
            ],
          ];
        }
        else {
          $date = $user_approval_request->get('changed')->value;
          $block['wrapper']['help'] = [
            '#markup' => $this->t('You %status this revision on @date.',
              [
                '%status' => $user_approval_request->getStatusName(),
                '@date' => date('d-M-Y', $date),
              ]),
            '#prefix' => '<p>',
            '#suffix' => '</p>',
          ];
        }
      }
      // Add information for users who can see it.
      if ($this->approverManager->isViewer()) {
        // @todo There may be a better way to handle this case.
        $approval_requests = $this->approverManager->getApprovalRequests($node);
        $pending = $blocking = 0;
        foreach ($approval_requests as $request) {
          if ($request->isPending()) {
            $pending++;
          }
          if ($request->isBlocking()) {
            $blocking++;
          }
        }
        if ($pending > 0) {
          if (!isset($block['wrapper'])) {
            $block['wrapper'] = [
              '#type' => 'fieldset',
            ];
          }
          $block['wrapper']['info'] = [
            '#markup' => $this->formatPlural($pending,
              'There is 1 <a href="@link">outstanding approval request</a> for this revision.',
              'There are @count <a href="@link">outstanding approval requests</a> for this revision.',
              [
                '@count' => $pending,
                '@link' => '/node/' . $node->id() . '/approver',
              ]),
            '#prefix' => '<p>',
            '#suffix' => '</p>',
          ];
        }
        if ($blocking > 0) {
          if (!isset($block['wrapper'])) {
            $block['wrapper'] = [
              '#type' => 'fieldset',
            ];
          }
          $block['wrapper']['blocked'] = [
            '#markup' => $this->t('This content may not be set to a new moderation state.'),
            '#prefix' => '<p>',
            '#suffix' => '</p>',
          ];
        }
      }
    }

    return $block;
  }

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    $permissions = [
      'use workbench approver',
      'view workbench approver information',
    ];
    return AccessResult::allowedIfHasPermissions($account, $permissions, 'OR');
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    return ['route.name', 'user'];
  }

  /**
   * Ensures that a destination is present on the given URL.
   *
   * @param \Drupal\Core\Url $url
   *   The URL object to which the destination should be added.
   *
   * @return \Drupal\Core\Url
   *   The updated URL object.
   */
  protected function ensureDestination(Url $url) {
    return $url->mergeOptions(['query' => $this->getRedirectDestination()->getAsArray()]);
  }

}
